# Generated by Django 4.1.6 on 2023-02-22 09:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "df_notifications",
            "0002_remove_notificationhistory_df_notifica_templat_fc63aa_idx_and_more",
        ),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="notificationhistory",
            name="df_notifica_templat_ec4b48_idx",
        ),
        migrations.RenameField(
            model_name="notificationhistory",
            old_name="template",
            new_name="template_prefix",
        ),
        migrations.AddIndex(
            model_name="notificationhistory",
            index=models.Index(
                fields=["template_prefix", "created"],
                name="df_notifica_templat_fc63aa_idx",
            ),
        ),
    ]



from fcm_django.api.rest_framework import FCMDeviceAuthorizedViewSet
from rest_framework import permissions
from rest_framework.mixins import ListModelMixin
from rest_framework.viewsets import GenericViewSet

from df_notifications.drf.serializers import (
    PushActionCategorySerializer,
    UserDeviceSerializer,
)
from df_notifications.models import PushActionCategory, UserDevice


class UserDeviceViewSet(FCMDeviceAuthorizedViewSet):
    queryset = UserDevice.objects.all()
    serializer_class = UserDeviceSerializer


class PushActionCategoryViewSet(ListModelMixin, GenericViewSet):
    queryset = PushActionCategory.objects.filter(is_active=True)
    permission_classes = (permissions.AllowAny,)
    serializer_class = PushActionCategorySerializer
    pagination_class = None



# Generated by Django 4.2.5 on 2023-11-16 09:35

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("df_notifications", "0007_custompushmessage"),
    ]

    operations = [
        migrations.AlterField(
            model_name="custompushmessage",
            name="action_url",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name="custompushmessage",
            name="audience",
            field=models.ManyToManyField(
                blank=True,
                help_text="Leave blank to send to all users",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AlterField(
            model_name="custompushmessage",
            name="sent",
            field=models.DateTimeField(
                blank=True, db_index=True, editable=False, null=True
            ),
        ),
    ]



# Generated by Django 4.1.5 on 2023-01-26 10:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("df_notifications", "0001_initial"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="notificationhistory",
            name="df_notifica_templat_fc63aa_idx",
        ),
        migrations.RenameField(
            model_name="notificationhistory",
            old_name="template_prefix",
            new_name="template",
        ),
        migrations.AddIndex(
            model_name="notificationhistory",
            index=models.Index(
                fields=["template", "created"], name="df_notifica_templat_ec4b48_idx"
            ),
        ),
    ]



from django.contrib import admin
from django.db.models import QuerySet
from django.http import HttpRequest
from fcm_django.admin import DeviceAdmin
from fcm_django.models import FCMDevice

from .models import (
    CustomPushMessage,
    NotificationHistory,
    PushAction,
    PushActionCategory,
    UserDevice,
)

admin.site.unregister(FCMDevice)


@admin.register(PushActionCategory)
class PushActionCategoryAdmin(admin.ModelAdmin):
    list_display = ("name", "is_active")


@admin.register(PushAction)
class PushActionAdmin(admin.ModelAdmin):
    list_display = (
        "name",
        "button_text",
        "authentication_required",
        "destructive",
        "foreground",
    )


@admin.register(UserDevice)
class UserDeviceAdmin(DeviceAdmin):
    pass


@admin.register(NotificationHistory)
class NotificationHistoryAdmin(admin.ModelAdmin):
    list_display = ("template_prefix", "channel", "instance_id", "created")
    date_hierarchy = "created"
    search_fields = (
        "template_prefix",
        "channel",
    )


@admin.register(CustomPushMessage)
class CustomPushMessageAdmin(admin.ModelAdmin):
    list_display = ("title", "created", "sent")
    date_hierarchy = "created"
    search_fields = ("title",)
    autocomplete_fields = ("audience",)

    def send(self, request: HttpRequest, queryset: QuerySet[CustomPushMessage]) -> None:
        for obj in queryset:
            obj.send()
        self.message_user(request, "Messages sent")

    send.short_description = "Send selected messages"

    actions = [send]
